const common = require('./webpack.config.common')
const { resolve } = require('path')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const InterpolateHtmlPlugin = require('./InterpolateHtmlPlugin');

const checkForLegacyErrors =  require("./check-for-legacy-errors");

const NOREACT = "true" == process.env.noReact || "true" == process.env.NOREACT 
const HTML = "true" == process.env.html || "true" == process.env.HTML
checkForLegacyErrors ();

module.exports = {
  mode: 'development',
  entry: {
    main: (NOREACT ? [resolve('src/index')] : [
      // resolve(__dirname, 'hotReload'),
      resolve('src/hotReload')
      // !!page && page != "default"
      //   ? resolve(__dirname, `../src/landing-pages/${page}/hotReload`)
      //   : resolve(__dirname, 'hotReload'),
    ])
  },
  // externals: common.externals,
  output: {
    filename: 'bundle.js',
    path: resolve('.'),
    clean: true
  },
  context: resolve('src'),
  resolve: common.resolve,
  devtool: 'inline-source-map',
  devServer: {
    proxy: [
      {
        context: ['/api'],
        target: 'http://localhost:3000', // Your API server
        changeOrigin: true,
        secure: false,
      },
      // Additional proxies can be defined here
    ],
  },
  module: {
    rules: [
      common.modules.purs,
      common.modules.ts,
      {
        test: /\.(scss|sass)$/,
        oneOf: [{
          resourceQuery: /^\?raw$/,
          use: [
            // 'css-hot-loader',
            'style-loader',
            'css-loader',
            common.loaders.postcss,
            common.loaders.sass,
          ]
        }, {
          use: [
            // 'css-hot-loader',
            'style-loader',
            'css-loader',
            common.loaders.postcss,
            common.loaders.sass,
          ]
        }]
      },
      {
        test: /\.styl$/,
        oneOf: [{
          resourceQuery: /^\?raw$/,
          use: [
            'css-hot-loader',
            'style-loader',
            'css-loader',
            common.loaders.postcss,
            common.loaders.stylus,
          ]
        }, {
          use: [
            'css-hot-loader',
            'style-loader',
            common.loaders["typings-for-css-camelCase"],
            common.loaders.postcss,
            common.loaders.stylus
          ]
        }]
      },
      {
        test: /\.(css|less)$/,
        oneOf: [{
          resourceQuery: /^\?raw$/,
          use: [
            'css-hot-loader',
            'style-loader',
            'css-loader',
            common.loaders.postcss,
            common.loaders.less,
          ]
        },
        {
          resourceQuery: /^\?dash-case$/,
          use: [
            'css-hot-loader',
            'style-loader',
            common.loaders["typings-for-css"],
            common.loaders.postcss,
            common.loaders.less,
          ]
        }, {
          use: [
            'css-hot-loader',
            'style-loader',
            common.loaders["typings-for-css-camelCase"],
            common.loaders.postcss,
            common.loaders.less,
          ]
        }]
      },
      common.modules.url,
    ],
  },
  optimization:{
    moduleIds: 'named'
  },
  plugins: [
    // new MiniCssExtractPlugin('style.css'),
    // new MiniCssExtractPlugin({
    //   // Options similar to the same options in webpackOptions.output
    //   // both options are optional
    //   filename: devMode ? '[name].css' : '[name].[hash].css',
    //   chunkFilename: devMode ? '[id].css' : '[id].[hash].css',
    // }),
    new HtmlWebpackPlugin({
      title: process.env.title,
      show_social_meta: process.env.show_social_meta,
      og_url: process.env.og_url,
      og_type: process.env.og_type,
      og_title: process.env.og_title,
      og_image: process.env.og_image,
      og_description: process.env.og_description,
      template: HTML ? resolve(`src/index.html`) : resolve(__dirname, 'template.html'),
    }),
    common.plugins.dotEnv,
    common.plugins.favicon,
    new InterpolateHtmlPlugin({
      'PUBLIC_URL': ''
    })
  ],
  performance: { hints: false },
}
