const HtmlWebpackPlugin = require('html-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const InterpolateHtmlPlugin = require('./InterpolateHtmlPlugin');
const { resolve } = require('path')
const webpack = require('webpack')
const path = require("path");
const envfile = require("envfile");
const env = envfile.parseFileSync(path.resolve("", ".env"));

require('dotenv').config()
const config = require("./webpack.config.prod.babel");
const page  = env.page

//config.entry = resolve(__dirname, '../src/index.ssr.ts') // "../src/index.ssr.ts";
config.entry = `./src/index.ssr.ts`;

config.output.filename = `static/${page}/ssr/[name].js`;
config.output.libraryTarget = "commonjs2";
delete config.output.chunkFilename;

config.target = "node";
config.externals = {
  react: 'commonjs react',
  'react-dom/server': 'commonjs react-dom/server',
  ...config.externals
}
//delete config.devtool;
config.plugins = [
  new webpack.DefinePlugin({
    'process.env': {
      'NODE_ENV': JSON.stringify("production"),
      'country': JSON.stringify(process.env.country || ''),
      'scenario': JSON.stringify(process.env.scenario || ''),
      'strategy': JSON.stringify(process.env.strategy || ''),
      'service': JSON.stringify(process.env.service || ''),
      'scenariosConfig': JSON.stringify(process.env.scenariosConfig || ''),
      'page': JSON.stringify(process.env.page || ''),
      'title': JSON.stringify(process.env.title || ''),
      'client': JSON.stringify(process.env.client || ''),
      'pacman_server': JSON.stringify(process.env.pacman_server || "https://de-pacman.analytickz.com/api/v2/mstore"),
    }
      // 'process.env.api_root': JSON.stringify(process.env.api_root || ''),
      // 'process.env.finance_email': JSON.stringify(process.env.finance_email || '')
  }),
  new MiniCssExtractPlugin({
    // Options similar to the same options in webpackOptions.output
    // both options are optional
    filename: `static/${page}/css/[name].[contenthash:8].css`,
    chunkFilename: 'static/css/[name].[contenthash:8].chunk.css',
  })

].filter((v)=>v !== null),

module.exports = config;
